# frozen_string_literal: true

module Contentful
  module Management
    module Resource
      # Useful methods for array-like resources that can be included if an
      # [#items] property exists
      module ArrayLike
        include Enumerable

        # Returns true for array-like resources
        def array?
          true
        end

        # Delegates to items#each
        def each_item(&block)
          items.each(&block)
        end

        alias each each_item

        # Delegates to items#empty?
        def empty?
          items.empty?
        end

        # Delegetes to items#size
        def size
          items.size
        end

        alias length size
      end
    end
  end
end
